import React, { useState } from "react";
import { useNavigate } from "react-router-dom"; // Use useNavigate instead
import "./AdminHome.css";

function AdminHome() {
  const navigate = useNavigate(); // Initialize useNavigate hook
  const [isSidebarOpen, setSidebarOpen] = useState(true);
  const [viewingUsers, setViewingUsers] = useState(false);
  const [firstName, setFirstName] = useState("");  // State for first name input
  const [lastName, setLastName] = useState("");   // State for last name input
  const [editingUser, setEditingUser] = useState(null);
  const [userData, setUserData] = useState({ name: "", email: "" });

  // Mock user data for demonstration
const [users, setUsers] = useState([
  {
    id: 1,
    firstName: "John",
    lastName: "Doe",
    middleName: "M.",
    suffix: "Jr.",
    maidenName: "Smith",
    nickname: "Johnny",
    gender: "male",
    techAlumChapter: "Chapter A",
    classYear: "2022",
    gradYear: "2023",
    gradSemester: "Fall",
    degrees: [
      {
        subject: "Computer Science",
        degreeType: "BS",
        degreeYear: "2022",
        degreeDescription: "Bachelor of Science in Computer Science",
        degreeDepartment: "Computer Science",
        degreeCollege: "College of Engineering",
      }
    ],
    addresses: [
      {
        address1: "123 Main St",
        address2: "Apt 4B",
        city: "Blacksburg",
        state: "VA",
        country: "USA",
        zipCode: "24060",
        preferredAddress: true,
      }
    ],
    contacts: [
      {
        contactNumber: "555-123-4567",
        contactType: "phone",
        preferredContact: true,
      }
    ],
    involvements: ["Alumni Association", "Volunteering"],
  },
  {
    id: 2,
    firstName: "Jane",
    lastName: "Smith",
    middleName: "A.",
    suffix: "Sr.",
    maidenName: "Doe",
    nickname: "Janie",
    gender: "female",
    techAlumChapter: "Chapter B",
    classYear: "2021",
    gradYear: "2022",
    gradSemester: "Spring",
    degrees: [
      {
        subject: "Biology",
        degreeType: "BS",
        degreeYear: "2021",
        degreeDescription: "Bachelor of Science in Biology",
        degreeDepartment: "Biology",
        degreeCollege: "College of Science",
      }
    ],
    addresses: [
      {
        address1: "456 Elm St",
        address2: "",
        city: "Roanoke",
        state: "VA",
        country: "USA",
        zipCode: "24012",
        preferredAddress: false,
      }
    ],
    contacts: [
      {
        contactNumber: "555-987-6543",
        contactType: "email",
        preferredContact: true,
      }
    ],
    involvements: ["Mentoring", "Research Group"],
  },
]);


  const toggleSidebar = () => {
    setSidebarOpen(!isSidebarOpen);
  };

  const handleViewUsersClick = () => {
    setViewingUsers(true);
  };

  const handleBackClick = () => {
    setViewingUsers(false);
    setEditingUser(null);
  };

  const handleCreateUser = () => {
    window.location.hash = "#MyAccountAdminView";
  };
  

  // Handle the search and redirect to results page
  const handleSearchSubmit = (e) => {
    e.preventDefault();
    const filteredUsers = users.filter(
      (user) =>
        user.firstName.toLowerCase().startsWith(firstName.toLowerCase()) &&
        user.lastName.toLowerCase().startsWith(lastName.toLowerCase())
    );

    // Redirect to the search results page with the filtered users
    navigate("/search-results", { state: { users: filteredUsers } }); // Use navigate instead

    // Reset the search inputs
    setFirstName("");
    setLastName("");
  };

  const handleSaveUser = (e) => {
    e.preventDefault();
    setUsers(
      users.map((user) =>
        user.id === editingUser
          ? {
              ...user,
              firstName: userData.name.split(" ")[0],
              lastName: userData.name.split(" ")[1],
              email: userData.email,
            }
          : user
      )
    );
    setEditingUser(null);
    setUserData({ name: "", email: "" });
  };

  return (
    <div className="admin-page">
      {/* Navbar */}
      {/* <nav className="navbar">
        <div className="navbar-links">
          <a href="#a">Home</a>
          <a href="#b">Browse</a>
          <a href="#c">Search</a>
          {/* <a href="#d">Messages</a> */}
        </div>
      </nav> */}

      <div className="main-content">
        {/* Sidebar */}
        <div className={`sidebar ${isSidebarOpen ? "open" : "closed"}`}>
          <button className="sidebar-toggle" onClick={toggleSidebar}>
            {isSidebarOpen ? "←" : "→"}
          </button>
          {isSidebarOpen && (
            <ul className="sidebar-menu">
              <li><a href="#e">Account Settings</a></li>
              <li><a href="#f">Privacy Policy</a></li>
              <li><a href="#g">What the app does?</a></li>
              <li><a href="#g">How can you use this app?</a></li>
              <li><a href="#g">Cadet Mission Statement </a></li>
            </ul>
          )}
        </div>

        {/* Dashboard */}
        <div className="content">
          <h1>Welcome to Admin Page</h1>
          <div className="dashboard">
            {viewingUsers ? (
              <>
                <button className="back-button" onClick={handleBackClick}>
                  ← Back to Dashboard
                </button>

                <button onClick={handleCreateUser}>
                  Create New User
                </button>

                {/* Search by First Name and Last Name */}
                <form className="search-area" onSubmit={handleSearchSubmit}>
                  <input
                    type="text"
                    placeholder="First Name"
                    className="search-input"
                    value={firstName}
                    onChange={(e) => setFirstName(e.target.value)}
                  />
                  <input
                    type="text"
                    placeholder="Last Name"
                    className="search-input"
                    value={lastName}
                    onChange={(e) => setLastName(e.target.value)}
                  />
                  <button
                    type="submit"
                    className="search-button"
                  >
                    Submit
                  </button>

                  
                </form>
           
                {/* Update User Form */}
                {editingUser && (
                  <div className="update-form">
                    <h3>Update User</h3>
                    <form onSubmit={handleSaveUser}>
                      <input
                        type="text"
                        placeholder="Name"
                        value={userData.name}
                        onChange={(e) =>
                          setUserData({ ...userData, name: e.target.value })
                        }
                        required
                      />
                      <input
                        type="email"
                        placeholder="Email"
                        value={userData.email}
                        onChange={(e) =>
                          setUserData({ ...userData, email: e.target.value })
                        }
                        required
                      />
                      <button type="submit">Save</button>
                      <button
                        type="button"
                        onClick={() => setEditingUser(null)}
                      >
                        Cancel
                      </button>
                    </form>
                  </div>
                )}
              </>
            ) : (
              <>
                <div className="dashboard-item" onClick={handleViewUsersClick}>
                  <span>View Users</span>
                </div>

                <div className="dashboard-item">
                  <input type="file" onChange={() => console.log("CSV Uploaded")} />
                  <span>Upload CSV</span>
                </div>
                <div className="dashboard-item" onClick={() => console.log("Tracking Page Visits")}>
                  <span>Track Application Activity</span>
                </div>
              </>
            )}
          </div>
        </div>
      </div>
    </div>
  );
}

export default AdminHome;
